@@ -82,7 +82,7 @@ my $max_mpi_ranks_filename = "max-mpi-ranks";
 
 # List of all the generic subdirectories of tests; pdb2gmx and essentialdynamics are treated
 # separately.
-my @all_dirs = ('complex', 'freeenergy', 'rotation', 'extra');
+my @all_dirs = ('complex', 'freeenergy', 'extra');
 
 # Return the command-line option specifying the number of separate
 # PME ranks to use, if appropriate (ie the .mdp file specifies a
@@ -692,7 +692,7 @@ sub test_case {
     my $grompp_mdp = "$input_dir/grompp.mdp";
     my $grompp_out = "grompp.out";
     my $grompp_err = "grompp.err";
-    $nerror = do_system("$progs{'grompp'} -f $grompp_mdp -c $input_dir/conf -r $input_dir/conf -p $input_dir/topol -ref $input_dir/rotref -maxwarn 10 $ndx >$grompp_out 2>$grompp_err");
+    $nerror = do_system("$progs{'grompp'} -f $grompp_mdp -c $input_dir/conf -r $input_dir/conf -p $input_dir/topol -maxwarn 10 $ndx >$grompp_out 2>$grompp_err");
 
     my @error_detail;
     if (! -f "topol.tpr") {
